@@ -17,7 +17,7 @@ Version 0.11
 
 =cut
 
-our $VERSION     = '0.11';
+our $VERSION     = '0.12';
 my  $OMIT_ROUTES = [];
 
 # Add syntactic sugar for omitting routes.
@@ -154,6 +154,9 @@ sub _retreive_get_urls {
                 # full route.
                 $pattern =~ s/\?//g;
 
+                # Only add any given route once.
+                next get_route if grep { $_ eq $pattern } @urls;
+
                 # Other than that, its cool to be added.
                 push (@urls, $pattern)
                     if ! grep { $pattern =~ m/$_/i }
